cmd

package
v0.0.0-...-fdf2b85 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2025 License: Apache-2.0 Imports: 33 Imported by: 0

Documentation

Overview

Package cmd contains the Cobra Command that implements the xk6 CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute executes root command.

func New

func New(levelVar *slog.LevelVar) *cobra.Command

New creates a new instance of Cobra Command, which implements the xk6 CLI.

Types

This section is empty.

Jump to